View source: R/hlao-computation.R
| hlaoEvent | R Documentation |
'hlaoEvent' describes the event that one alternative is strictly preferred to every alternative in a supplied comparison set. Unlike an indicator over enumerated rankings, this representation can be priced directly by the H-LAO column-generation algorithm.
hlaoEvent(alternative, preferred_to, name = NULL)
alternative |
Integer identifying the focal alternative. |
preferred_to |
Distinct integers identifying alternatives that the focal alternative must be preferred to. |
name |
Optional event label. |
An object of class 'ramchoiceHLAOEvent'.
M. D. Cattaneo, P. H. Y. Cheung, X. Ma, and Y. Masatlioglu (2026). Attention Overload. Working paper.
hlaoEvent(4, 1, name = "4 above 1")
hlaoEvent(1, c(2, 3, 4), name = "1 top ranked")
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.